summaryrefslogtreecommitdiff
path: root/libre-testing/systemd/0005-FSDG-systemd-resolved-Fallback-hostname-to-gnu-linux.patch
blob: 5e170ce3476997cdb230f4e8a2914f8ab856d862 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
From 50b001e3d034825142c03e612af9d4a5a307472f Mon Sep 17 00:00:00 2001
From: Luke Shumaker <lukeshu@parabola.nu>
Date: Wed, 25 May 2016 12:31:20 -0400
Subject: [PATCH 5/7] FSDG: systemd-resolved: Fallback hostname to "gnu-linux"
 instead of "linux"

---
 src/resolve/resolved-manager.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/resolve/resolved-manager.c b/src/resolve/resolved-manager.c
index 01372fc66b..9155ce5c2e 100644
--- a/src/resolve/resolved-manager.c
+++ b/src/resolve/resolved-manager.c
@@ -387,10 +387,10 @@ static int determine_hostname(char **full_hostname, char **llmnr_hostname, char
 static const char *fallback_hostname(void) {
 
         /* Determine the fall back hostname. For exposing this system to the outside world, we cannot have it to be
          * "localhost" even if that's the compiled in hostname. In this case, let's revert to "linux" instead. */
 
         if (is_localhost(FALLBACK_HOSTNAME))
-                return "linux";
+                return "gnu-linux";
 
         return FALLBACK_HOSTNAME;
 }
@@ -387,10 +387,10 @@ static int determine_hostname(char **full_hostname, char **llmnr_hostname, char
 
         /* Determine the fall back hostname. For exposing this system to the outside world, we cannot have it to be
-         * "localhost" even if that's the compiled in hostname. In this case, let's revert to "linux" instead. */
+         * "localhost" even if that's the compiled in hostname. In this case, let's revert to "gnu-linux" instead. */
 
         if (is_localhost(FALLBACK_HOSTNAME))
-- 
2.18.0